==> dxt-explorer-0.2.tar.gz: dxt-explorer-0.2/README.md <==
<p align="center">
  <img src="https://github.com/hpc-io/dxt-explorer/raw/main/dxt-explorer.png" alt="DXT Explorer"/>
</p>

DXT Explorer is an interactive web-based log analysis tool to visualize Darshan DXT logs and help understand the I/O behavior of applications. Our tool adds an interactive component to Darshan trace analysis that can aid researchers, developers, and end-users to visually inspect their applications' I/O behavior, zoom-in on areas of interest and have a clear picture of where is the I/O problem. 

### Documentation

You can find our complete documentation at [dxt-explorer.readthedocs.io](https://dxt-explorer.readthedocs.io).

### Citation

You can find more information about DXT Explorer in our PDSW'21 paper. If you use DXT in your experiments, please consider citing:

```
@inproceedings{dxt-explorer,
  title = {{I/O Bottleneck Detection and Tuning: Connecting the Dots using Interactive Log Analysis}},
  author = {Bez, Jean Luca and Tang, Houjun and Xie, Bing, and Williams-Young, David and Latham, Rob and Ross, Rob and Oral, Sarp and Byna, Suren},
  booktitle = {2021 IEEE/ACM 6th International Parallel Data Systems Workshop (PDSW)}
  year = {2021}
}
```
---

DXT Explorer Copyright (c) 2021, The Regents of the University of California, through Lawrence Berkeley National Laboratory (subject to receipt of any required approvals from the U.S. Dept. of Energy). All rights reserved.

If you have questions about your rights to use or distribute this software, please contact Berkeley Lab's Intellectual Property Office at IPO@lbl.gov.

NOTICE.  This Software was developed under funding from the U.S. Department of Energy and the U.S. Government consequently retains certain rights.  As such, the U.S. Government has been granted for itself and others acting on its behalf a paid-up, nonexclusive, irrevocable, worldwide license in the Software to reproduce, distribute copies to the public, prepare derivative works, and perform publicly and display publicly, and to permit others to do so.

==> dxt-explorer-0.3.tar.gz: dxt-explorer-0.3/README.md <==
<p align="center">
  <img src="https://github.com/hpc-io/dxt-explorer/raw/main/dxt-explorer.png" alt="DXT Explorer"/>
</p>

DXT Explorer is an interactive web-based log analysis tool to visualize Darshan DXT logs and help understand the I/O behavior of applications. Our tool adds an interactive component to Darshan trace analysis that can aid researchers, developers, and end-users to visually inspect their applications' I/O behavior, zoom-in on areas of interest and have a clear picture of where is the I/O problem. 

### Documentation

You can find our complete documentation at [dxt-explorer.readthedocs.io](https://dxt-explorer.readthedocs.io).

### Citation

You can find more information about DXT Explorer in our PDSW'21 paper. If you use DXT in your experiments, please consider citing:

```
@inproceedings{dxt-explorer,
   title = {{I/O Bottleneck Detection and Tuning: Connecting the Dots using Interactive Log Analysis}},
   author = {Bez, Jean Luca and Tang, Houjun and Xie, Bing and Williams-Young, David and Latham, Rob and Ross, Rob and Oral, Sarp and Byna, Suren},
   booktitle = {2021 IEEE/ACM Sixth International Parallel Data Systems Workshop (PDSW)},
   year = {2021},
   volume = {},
   number = {},
   pages = {15-22},
   doi = {10.1109/PDSW54622.2021.00008}
}
```
---

DXT Explorer Copyright (c) 2021, The Regents of the University of California, through Lawrence Berkeley National Laboratory (subject to receipt of any required approvals from the U.S. Dept. of Energy). All rights reserved.

If you have questions about your rights to use or distribute this software, please contact Berkeley Lab's Intellectual Property Office at IPO@lbl.gov.

NOTICE.  This Software was developed under funding from the U.S. Department of Energy and the U.S. Government consequently retains certain rights.  As such, the U.S. Government has been granted for itself and others acting on its behalf a paid-up, nonexclusive, irrevocable, worldwide license in the Software to reproduce, distribute copies to the public, prepare derivative works, and perform publicly and display publicly, and to permit others to do so.
